package nl.backend;

import java.util.List;

import javax.ejb.Stateless;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.persistence.Query;

@Stateless
public class NewsLetterBean implements NewsLetter {
	
    @PersistenceContext(unitName = "nl-backend")
    private EntityManager entityManager;
	
	/* (non-Javadoc)
	 * @see nl.backend.NewsLetter#create(java.lang.String, java.lang.String)
	 */
	public void create(String name, String email) {
		User user = new User(name, email);
		this.entityManager.persist(user);
		
		this.sendMail(user);
		
	}

	private void sendMail(User user) {
		MailUtil.send(
				user, 
				"Newsletter Registration", 
				"Hallo "
				+ user.getName()
				+ " bitte den Link klicken zur Bestttigung "
				+ "http://localhost:8080/nl-frontend/confirm/?id="
				+ user.getId()
		);
		
	}
	
	/* (non-Javadoc)
	 * @see nl.backend.NewsLetter#find(java.lang.Boolean)
	 */
	public List<User> find(Boolean onlyConfirmed) {
		Query query;
		if(Boolean.TRUE.equals(onlyConfirmed)) {
			query = this.entityManager.createQuery("select u from User u where u.confirmed = true");
		} else {
			query = this.entityManager.createQuery("select u from User u");
		}
		
		return query.getResultList();
		
	}

	/* (non-Javadoc)
	 * @see nl.backend.NewsLetter#confirm(java.lang.Long)
	 */
	public User confirm(Long id) {
		User user = entityManager.find(User.class, id);
		user.setConfirmed(true);
		
		return user;
	}

}
